#Replication code
#to the paper
#The Democratic Cost of Consecutive Re-election and Presidential Term Limit Evasion in Latin America


##### Upload libraries --------------------------------------------------------


#For all R simulations (R version 4.0.0) in this study it is necessary to upload following R libraries:
{library(panelView)
library(psych)
library(sampleSelection)
library(stargazer)
library(plm)
library(MatchIt)
library(ggplot2)
library(Hmisc)
library(dplyr)
library(patchwork)
library(gridExtra)
library(gsynth)
library(car)}


##### Upload data -------------------------------------------------------------


#For the purpose of this paper we prepared 3 datasets (MatchingData; OLSData; SyntheticData):
{load("Datasets.RData")
OLSData <- data.frame(OLSData)
MatchingData <- data.frame(MatchingData)
SyntheticData <- data.frame(SyntheticData)}


##### Data visualization and descriptive statistics ---------------------------


#Figure 1. Tretated, control and missing units in the analysis of reelection rules in Latin American countries, 1945-2018
panelView(v2x_libdem ~ Reeligibility_status_code, data = OLSData,  index = c("country","year"), by.timing = TRUE, pre.post = TRUE, legend.labs = c("(1) Not elected", "(2) Control units", "(3) Treated units"), axis.adjust=TRUE, axis.lab.gap = c(1,0))

#Figure 2. Latin American countries by treatment status, 1983-2018
{p20 <- panelView(v2x_libdem ~ treatment, data = SyntheticData,  index = c("country","year"), pre.post = TRUE, by.timing = TRUE) + theme(axis.text.x = element_text(angle = 90, size = 7, vjust = 0))
p21 <- panelView(v2x_libdem ~ treatment, data = SyntheticData,  index = c("country","year"), type = "outcome", main = "Re-election reform and LIBDEM", by.group = TRUE, color = c("black", "grey"))
p20 + p21}

#Tables A1-A2. Descriptive statistics (Group by Treatment)
describeBy(OLSData, OLSData$treatment)

#Table A3-A4. Descriptive statistics (Group by Elected)
describeBy(OLSData, OLSData$Elected)

#Table A5. Descriptive statistics (Complete dataset)
describeBy(OLSData)

#Figure A1. Estimated densities and the raw data points using all data since 1945, Liberal Democracy outcome by each Reeligibility status
{g <-ggplot(OLSData, aes(x = Reeligibility_status, y = v2x_libdem), by.group = TRUE)+labs(x = "Status", y = "Liberal Democracy Index")
p1<-g + geom_boxplot(fill = "indianred")
p1a<-g + geom_violin(aes(color = Reeligibility_status), fill = "gray80", alpha = 0.5) +geom_jitter(aes(color = Reeligibility_status), alpha = 0.25,position = position_jitter(width = 0.3)) +theme(legend.position = "none") +coord_flip()
p1+p1a}

#Figure A2. Estimated densities and the raw data points using all data since 1945, Vertical Accountability outcome by each Reeligibility status
{g2 <-ggplot(OLSData, aes(x =Reeligibility_status, y = v2x_veracc_osp), by.group = TRUE) +labs(x = "Status", y = "Vertical Accountability Index")
p2<-g2 + geom_boxplot(fill = "indianred")
p2a<-g2 + geom_violin(aes(color = Reeligibility_status), fill = "gray80", alpha = 0.5) +geom_jitter(aes(color = Reeligibility_status), alpha = 0.25,position = position_jitter(width = 0.3)) +theme(legend.position = "none") +coord_flip()
p2+p2a}

#Figure A3. Estimated densities and the raw data points using all data since 1945, Horizontal Accountability outcome by each Reeligibility status
{g3<-ggplot(OLSData,aes(x = Reeligibility_status, y =v2x_horacc_osp),by.group = TRUE)+labs(x ="Status", y ="Horizontal Accountability Index")
p3<-g3+geom_boxplot(fill ="indianred")
p3a<-g3+geom_violin(aes(color=Reeligibility_status), fill = "gray80", alpha = 0.5)+geom_jitter(aes(color=Reeligibility_status), alpha = 0.25,position = position_jitter(width = 0.3))+theme(legend.position ="none")+coord_flip()
p3+p3a}


##### OLS Models --------------------------------------------------------------

#Table A6. OLS Models: Variance Inflation Factor - Full model (Liberal Democracy Index as an outcome)
{vif_ols = lm(v2x_libdem ~ treatment + HDI + GDPpc_avg + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
summary(vif_ols)}
{vif(vif_ols)}

#Figure A4. Variance Inflation Factor - Full model (Liberal Democracy Index as an outcome)
{vif_values <- vif(vif_ols)
barplot(vif_values, main = "VIF Values", horiz = TRUE, col = "steelblue")}


#Table 1. OLS Models: Liberal Democracy Index as the outcome
{hols1 = lm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
hols1a = lm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
hols1b = lm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
hgls1fe = plm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
hgls1re1 = plm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
hgls1re2 = plm(v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_libdemY1, data=subset(OLSData, Elected==1), model="random")
hheck1 = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
hheck1a = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ treatment + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)

stargazer(hols1, hols1a, hols1b, hgls1fe, hgls1re1, hgls1re2, hheck1, hheck1a, type="text", out = "Table 1.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c( "Treatment", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Liberal Democracy Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.","Heckman HDI", "Heckman GDP"))}


#Table 2. OLS Models: Vertical Accountability Index as the outcome
{hols2 = lm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
hols2a = lm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
hols2b = lm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
hgls2fe = plm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
hgls2re1 = plm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
hgls2re2 = plm(v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_veracc_ospY1, data=subset(OLSData, Elected==1), model="random")
hheck2 = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
hheck2a = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ treatment + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)

stargazer(hols2, hols2a, hols2b, hgls2fe, hgls2re1, hgls2re2, hheck2, hheck2a, type="text", df=TRUE, out = "Table 2.html",single.row = F,digits=2, no.space=TRUE, covariate.labels=c( "Treatment", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Vertical Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.","Heckman HDI", "Heckman GDP"))}


#Table 3. OLS Models: Horizontal Accountability Index the an outcome
{hols3 = lm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
hols3a = lm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
hols3b = lm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
hgls3fe = plm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
hgls3re1 = plm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
hgls3re2 = plm(v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_horacc_ospY1, data=subset(OLSData, Elected==1), model="random")
hheck3 = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
hheck3a = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ treatment + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)

stargazer(hols3, hols3a, hols3b, hgls3fe, hgls3re1, hgls3re2, hheck3, hheck3a, type="text", df=TRUE, out = "Table 3.html",single.row = F,digits=2, no.space=TRUE, covariate.labels=c( "Treatment", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Horizontal Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.","Heckman HDI", "Heckman GDP"))}

  
#Table A7. OLS Models: Egalitarian Democracy Index as the outcome
{ols4 = lm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols4a = lm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols4b = lm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls4fe = plm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls4re1 = plm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls4re2 = plm(v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_egaldemY1, data=subset(OLSData, Elected==1), model="random")
  heck4 = heckit(Elected ~ v2x_libdem,v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck4a = heckit(Elected ~ v2x_libdem,v2x_egaldem ~ treatment + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols4, ols4a, ols4b, gls4fe, gls4re1, gls4re2, heck4, heck4a, type="text",out = "Table A7.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c( "Treatment", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Egalitarian Democracy Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.","Heckman HDI", "Heckman GDP"))}


#Table A8. OLS Models: Civil Liberties (Freedom House Index) as the outcome
{ols6 = lm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols6a = lm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols6b = lm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls6fe = plm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls6re1 = plm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls6re2 = plm(CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party + CL_FHY1, data=subset(OLSData, Elected==1), model="random")
  heck6 = heckit(Elected ~ v2x_egaldem,CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck6a = heckit(Elected ~ v2x_egaldem,CL_FH ~ treatment + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols6, ols6a, ols6b, gls6fe, gls6re1, gls6re2, heck6, heck6a, type="text",out = "Table A8.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c( "Treatment", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Civil Liberties", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.","Heckman HDI", "Heckman GDP"))}


#Table A9. OLS Models: Liberal Democracy Index as the outcome (whether the president is facing term limits BEYOND the next term or whether any future term limits are completely removed)
{ols8 = lm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols8a = lm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols8b = lm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls8fe = plm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls8re1 = plm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls8re2 = plm(v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_libdemY1, data=subset(OLSData, Elected==1), model="random")
  heck8 = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck8a = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ a_no_future_term_limit + a_term_limit + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols8, ols8a, ols8b, gls8fe, gls8re1, gls8re2, heck8, heck8a, type="text", out = "Table A9.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("No future term limit","Term limit", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Liberal Democracy Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}

#Table A10. OLS Models: Vertical Accountability Index as the outcome (whether the president is facing term limits BEYOND the next term or whether any future term limits are completely removed)
{ols9 = lm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols9a = lm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols9b = lm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls9fe = plm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls9re1 = plm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls9re2 = plm(v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_veracc_ospY1, data=subset(OLSData, Elected==1), model="random")
  heck9 = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck9a = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ a_no_future_term_limit + a_term_limit + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols9, ols9a, ols9b, gls9fe, gls9re1, gls9re2, heck9, heck9a, type="text", out = "Table A10.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("No future term limit","Term limit", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Vertical Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}

#Table A11. OLS Models: Horizontal Accountability Index as the outcome (whether the president is facing term limits BEYOND the next term or whether any future term limits are completely removed)
{ols10 = lm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols10a = lm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols10b = lm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls10fe = plm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls10re1 = plm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls10re2 = plm(v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_horacc_ospY1, data=subset(OLSData, Elected==1), model="random")
  heck10 = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck10a = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ a_no_future_term_limit + a_term_limit + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols10, ols10a, ols10b, gls10fe, gls10re1, gls10re2, heck10, heck10a, type="text", out = "Table A11.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("No future term limit","Term limit", "HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Horizontal Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}

#Table A12. OLS Models: Liberal Democracy Index as the outcome (whether the presidents escape accountability in their second terms in which they cannot be reelected compared to their first terms after which they are eligible for an immediate reelection)
{ols11 = lm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols11a = lm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols11b = lm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls11fe = plm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls11re1 = plm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls11re2 = plm(v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_libdemY1, data=subset(OLSData, Elected==1), model="random")
  heck11 = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck11a = heckit(Elected ~ v2x_egaldem,v2x_libdem ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols11, ols11a, ols11b, gls11fe, gls11re1, gls11re2, heck11, heck11a, type="text", out = "Table A12.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("Second term","No future term limits", "Term limits - other than second term","HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Liberal Democracy Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}


#Table A13. OLS Models: Vertical Accountability Index as the outcome (whether the presidents escape accountability in their second terms in which they cannot be reelected compared to their first terms after which they are eligible for an immediate reelection)
{ols12 = lm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols12a = lm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols12b = lm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls12fe = plm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls12re1 = plm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls12re2 = plm(v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_veracc_ospY1, data=subset(OLSData, Elected==1), model="random")
  heck12 = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck12a = heckit(Elected ~ v2x_egaldem,v2x_veracc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols12, ols12a, ols12b, gls12fe, gls12re1, gls12re2, heck12, heck12a, type="text", out = "Table A13.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("Second term","No future term limits", "Term limits - other than second term","HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Vertical Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}

#Table A14. OLS Models: Horizontal Accountability Index as the outcome (HDI as a covariate; hypothesis, that the presidents escape accountability in their second terms in which they cannot be reelected compared to their first terms after which they are eligible for an immediate reelection)
{ols13 = lm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1))
  ols13a = lm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year < 1990))
  ols13b = lm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1 & year > 1989))
  gls13fe = plm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="within")
  gls13re1 = plm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data=subset(OLSData, Elected==1), model="random")
  gls13re2 = plm(v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party + v2x_horacc_ospY1, data=subset(OLSData, Elected==1), model="random")
  heck13 = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
  heck13a = heckit(Elected ~ v2x_egaldem,v2x_horacc_osp ~ b_second_term + b_no_future_term_limit + b_tern_limit_other_than_second_term + NatRes_GDP + GINI_avg + v2xps_party + GDPpc_avg, data= OLSData)
  
  stargazer(ols13, ols13a, ols13b, gls13fe, gls13re1, gls13re2, heck13, heck13a, type="text", out = "Table A14.html", df=TRUE, single.row = F,digits=2, no.space=TRUE, covariate.labels=c("Second term","No future term limits", "Term limits - other than second term","HDI", "Natural Resurces (%of GDP)","GINI","Party Institutionalization Index", "Lag of Horizontal Accountability Index", "GDP per capita"), column.labels=c("1945-2018","1945-1989","1990-2018","FE","RE","RE with lagged dem.", "Heckman HDI", "Heckman GDP"))}

#Table A15. Heckman selection coefficients for all outcomes with HDI as the covariate in each selection phase (Tobit 2 model)
{heck111 = heckit(Elected ~ v2x_egaldem, v2x_libdem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
summary(heck111)}
{heck211 = heckit(Elected ~ v2x_egaldem, v2x_veracc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
summary(heck211)}
{heck311 = heckit(Elected ~ v2x_egaldem, v2x_horacc_osp ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
summary(heck311)}
{heck411 = heckit(Elected ~ v2x_libdem, v2x_egaldem ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
summary(heck411)}
{heck511 = heckit(Elected ~ v2x_egaldem,CL_FH ~ treatment + HDI + NatRes_GDP + GINI_avg + v2xps_party, data= OLSData)
summary(heck511)}


##### Propensity score Matching -----------------------------------------------


#Table A17. Difference in means of outcome variables and pretreatment covariates (Welch Two Sample t-test before matching)
{MatchingData %>%
  group_by(treatment) %>%
  summarise(n_case = n(),
            mean_LIBDEM = mean(v2x_libdem),
            std_error = sd(v2x_libdem) / sqrt(n_case))}
{MatchingData %>%
  group_by(treatment) %>%
  summarise(n_case = n(),
            mean_VERACC = mean(v2x_veracc_osp),
            std_error = sd(v2x_libdem) / sqrt(n_case))}
{MatchingData %>%
  group_by(treatment) %>%
  summarise(n_case = n(),
            mean_HORACC = mean(v2x_horacc_osp),
            std_error = sd(v2x_libdem) / sqrt(n_case))}

{MatchingData_cov <- c('GDPpc_avg', 'HDI', 'NatRes_GDP', 'v2xps_party', 'GINI_avg')
MatchingData %>%
  group_by(treatment) %>%
  select(one_of(MatchingData_cov)) %>%
  summarise_all(funs(mean(., na.rm = T)))}

lapply(MatchingData_cov, function(v) {t.test(MatchingData[, v] ~ MatchingData[, 'treatment'])})

#Propensity score estimation
{m_ps <- glm(treatment ~ GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, family = binomial(), data = MatchingData)
prs_df <- data.frame(pr_score = predict(m_ps, type = "response"),
                     treatment = m_ps$model$treatment)
head(prs_df)}

#Figure A5. Histogram of the estimated propensity scores by treatment status
{labs <- paste("Permisive Reform occured:", c("Yes", "No"))
prs_df %>%
  mutate(treatment = ifelse(treatment == 1, labs[1], labs[2])) %>%
  ggplot(aes(x = pr_score)) +
  geom_histogram(color = "white") +
  facet_wrap(~treatment) +
  xlab("Probability of Permisive Reform occured") + theme_bw()}


#Figure A6. Propensity score before matching
{MatchingData$psvalue <- predict(m_ps, type = "response") 
histbackback(split(MatchingData$psvalue, MatchingData$treatment), main= "Propensity score before matching", xlab=c("control", "treatment"))
}

#Matching algorithm
{MatchingData_nomiss <- MatchingData %>%    select(v2x_libdem, treatment, one_of(MatchingData_cov)) %>%
  na.omit()
mod_match <- matchit(treatment ~ GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, method = "nearest", data = MatchingData_nomiss)
MatchingData_nomiss1 <- MatchingData %>%    select(v2x_veracc_osp, treatment, one_of(MatchingData_cov)) %>%
  na.omit()
mod_match1 <- matchit(treatment ~ GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, method = "nearest", data = MatchingData_nomiss1)
MatchingData_nomiss2 <- MatchingData %>%    select(v2x_horacc_osp, treatment, one_of(MatchingData_cov)) %>%
  na.omit()
mod_match2 <- matchit(treatment ~ GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party,method = "nearest", data = MatchingData_nomiss2)}
{dta_m <- match.data(mod_match)
dim(dta_m)}
{dta_m1 <- match.data(mod_match1)
dim(dta_m1)}
{dta_m2 <- match.data(mod_match2)
dim(dta_m2)
}
#Examining covariate balance in the matched sample

#Table A18. Difference-in-means of posttreatment covariates and treatment effects of outcomes
dta_m %>%
  group_by(treatment) %>%
  select(one_of(MatchingData_cov)) %>% summarise_all(funs(mean))
lapply(MatchingData_cov, function(v) {t.test(dta_m[, v] ~ dta_m$treatment)})

with(dta_m, t.test(v2x_libdem ~ treatment))
with(dta_m1, t.test(v2x_veracc_osp ~ treatment)) 
with(dta_m2, t.test(v2x_horacc_osp ~ treatment))

#Figure A7 - Propensity score after matching
histbackback(split(dta_m$distance, dta_m$treatment), main= "Propensity score after matching", xlab=c("control", "treatment"))

#Figure A10. The mean of covariates against the estimated propensity score by treatment status#
fn_bal <- function(dta, variable){
  dta$variable <- dta[, variable]
  if (variable == 'v2x_libdem') dta$variable <- dta$variable
  dta$treatment <- as.factor(dta$treatment)
  support <- c(min(dta$variable), max(dta$variable))
  ggplot(dta, aes(x = distance, y = variable, color = treatment)) +
    geom_point(alpha = 0.2, size = 1.3) +
    geom_smooth(method = "loess", se = F) +
    xlab("Propensity score") +
    ylab(variable) +
    theme_bw() +
    ylim(support)}
grid.arrange(
  fn_bal(dta_m, "NatRes_GDP"),
  fn_bal(dta_m, "v2xps_party"),
  fn_bal(dta_m, "HDI"),
  fn_bal(dta_m, "GDPpc_avg"),
  fn_bal(dta_m, "GINI_avg"),nrow = 3, widths = c(1, 1))

#Figure A9. Distribution of propensity scores
plot(mod_match, type = "jitter")
# press "Esc" to finish the jitter plot

#Figure A8. Histogram of the matched and raw data
plot(mod_match, type = "hist")

#Table A16. Re-eligibility and democracy in matched samples in Latin America, 1945-2018
{lm_treat1a <- lm(v2x_libdem ~ treatment, data = dta_m)
summary(lm_treat1a)}
{lm_treat1b <- lm(v2x_libdem ~ treatment + GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, data = dta_m)
summary(lm_treat1b)}
{lm_treat2a <- lm(v2x_veracc_osp ~ treatment, data = dta_m1)
summary(lm_treat2a)}
{lm_treat2b <- lm(v2x_veracc_osp ~ treatment + GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, data = dta_m1)
summary(lm_treat2b)}
{lm_treat3a <- lm(v2x_horacc_osp ~ treatment, data = dta_m2)
summary(lm_treat3a)}
{lm_treat3b <- lm(v2x_horacc_osp ~ treatment + GDPpc_avg + HDI + NatRes_GDP + GINI_avg + v2xps_party, data = dta_m2)
summary(lm_treat3b)}

stargazer(lm_treat1a, lm_treat1b, lm_treat2a, lm_treat2b, lm_treat3a, lm_treat3b, align=TRUE, type="text", out = "Table 4.html", no.space=TRUE)


##### Synthetic control Method ------------------------------------------------


#Estimation - Matrix Completion Method
{outMCLIBDEM <- gsynth(v2x_libdem ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, estimator = "mc", index = c("country","year"), se = TRUE, nboots = 1000, min.T0 = 7, r = c(0, 5), CV = TRUE, force = "two-way", parallel = TRUE)
outMCVERACC <- gsynth(v2x_veracc_osp ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, estimator = "mc", index = c("country","year"), se = TRUE, nboots = 1000, min.T0 = 7, r = c(0, 5), CV = TRUE, force = "two-way", parallel = TRUE)
outMCHORACC <- gsynth(v2x_horacc_osp ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, estimator = "mc", index = c("country","year"), se = TRUE, nboots = 1000, min.T0 = 7, r = c(0, 5), CV = TRUE, force = "two-way", parallel = TRUE)}

#Results (MC Method)
#Table 5. Average treatment effect of term limit evasion on three democratic outcomes(MC Method)
outMCLIBDEM$est.avg
outMCVERACC$est.avg
outMCHORACC$est.avg

#Table A19. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Liberal Democracy Index as an outcome(MC Method)
outMCLIBDEM$est.att

#Table A20. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Vertical Accountability Index as an outcome(MC Method)
outMCVERACC$est.att

#Table A21. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Horizontal Accountability Index as an outcome(MC Method)
outMCHORACC$est.att

#Table A22. Coefficients for covariates (Liberal Democracy Index as an outcome)(MC Method)
outMCLIBDEM$est.beta

#Table A23. Coefficients for covariates (Vertical Accountability Index as an outcome)(MC Method)
outMCVERACC$est.beta

#Table A24. Coefficients for covariates (Horizontal Accountability Index as an outcome)(MC Method)
outMCHORACC$est.beta

#Figure 3. The effect of term limit evasion on the three democratic outcomes in Latin America, 1983-2018(MC Method).
{p1 <-  plot(outMCLIBDEM, type = "gap", ylab = "Liberal Democracy", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("MC ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
p2 <-  plot(outMCLIBDEM, type = "ct", ylab = "Liberal Democracy", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("MC Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
p3 <-  plot(outMCVERACC, type = "gap", ylab = "Vertical Accountability", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("MC ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
p4 <-  plot(outMCVERACC, type = "ct", ylab = "Vertical Accountability", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("MC Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
p5 <-  plot(outMCHORACC, type = "gap", ylab = "Horizontal Accountability", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("MC ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
p6 <-  plot(outMCHORACC, type = "ct", ylab = "Horizontal Accountability", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("MC Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))}


#Figure 4. The effect of term limit evasion on the three democratic outcomes by Latin American countries(MC Method)
{p7 <-  plot(outMCLIBDEM, type = "ct", id = "Argentina", ylab = "Liberal Democracy", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p8 <-  plot(outMCLIBDEM, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p9 <-  plot(outMCLIBDEM, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p10 <-  plot(outMCLIBDEM, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Liberal Democracy",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p11 <-  plot(outMCLIBDEM, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p12 <-  plot(outMCLIBDEM, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p13 <-  plot(outMCLIBDEM, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p14 <-  plot(outMCLIBDEM, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p15 <-  plot(outMCLIBDEM, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p16 <-  plot(outMCLIBDEM, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))

p17 <-  plot(outMCVERACC, type = "ct", id = "Argentina", ylab = "Vertical Accountability", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p18 <-  plot(outMCVERACC, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p19 <-  plot(outMCVERACC, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p20 <-  plot(outMCVERACC, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Vertical Accountability",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p21 <-  plot(outMCVERACC, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p22 <-  plot(outMCVERACC, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p23 <-  plot(outMCVERACC, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p24 <-  plot(outMCVERACC, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p25 <-  plot(outMCVERACC, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p26 <-  plot(outMCVERACC, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))

p27 <-  plot(outMCHORACC, type = "ct", id = "Argentina", ylab = "Horizontal Accountability", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p28 <-  plot(outMCHORACC, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p29 <-  plot(outMCHORACC, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p30 <-  plot(outMCHORACC, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Horizontal Accountability",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p31 <-  plot(outMCHORACC, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p32 <-  plot(outMCHORACC, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p33 <-  plot(outMCHORACC, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p34 <-  plot(outMCHORACC, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p35 <-  plot(outMCHORACC, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
p36 <-  plot(outMCHORACC, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))}


#Estimation - EM Method
{outEMLIBDEM <- gsynth(v2x_libdem ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, index = c("country","year"), se = TRUE, inference="parametric", nboots = 1000, min.T0 = 7, r = c(0, 5), EM=TRUE, CV = TRUE, force = "two-way", parallel = TRUE, seed=02139)

outEMVERACC <- gsynth(v2x_veracc_osp ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, index = c("country","year"), se = TRUE, inference="parametric", nboots = 1000, min.T0 = 7, r = c(0, 5), EM=TRUE, CV = TRUE, force = "two-way", parallel = TRUE, seed=02139)

outEMHORACC <- gsynth(v2x_horacc_osp ~ treatment + GINI_avg + GDPpc_avg + HDI + NatRes_GDP + v2xps_party, data = SyntheticData, index = c("country","year"), se = TRUE, inference="parametric",  nboots = 1000, min.T0 = 7, r = c(0, 5), EM=TRUE, CV = TRUE, force = "two-way", parallel = TRUE, seed=02139)}

#Results(EM Method)
#Table A25. Average treatment effect of term limit evasion on three democratic outcomes (EM Method)
outEMLIBDEM$est.avg
outEMVERACC$est.avg
outEMHORACC$est.avg

#Table A26. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Liberal Democracy Index as an outcome(EM Method)
outEMLIBDEM$est.att

#Table A27. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Vertical Accountability Index as an outcome(EM Method)
outEMVERACC$est.att

#Table A28. Average Treatment Effect on the Treated by Period (including Pre-treatment Periods) with Horizontal Accountability Index as an outcome(EM Method)
outEMHORACC$est.att

#Table A29. Coefficients for covariates (Liberal Democracy Index as an outcome)(EM Method)
outEMLIBDEM$est.beta

#Table A30. Coefficients for covariates (Vertical Accountability Index as an outcome)(EM Method)
outEMVERACC$est.beta

#Table A31. Coefficients for covariates (Horizontal Accountability Index as an outcome)(EM Method)
outEMHORACC$est.beta

#Figure A11. The effect of term limit evasion on the three democratic outcomes in Latin America, 1983-2018(MC Method).
{pem1 <-  plot(outEMLIBDEM, type = "gap", ylab = "Liberal Democracy", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("EM ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
pem2 <-  plot(outEMLIBDEM, type = "ct", ylab = "Liberal Democracy", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("EM Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
pem3 <-  plot(outEMVERACC, type = "gap", ylab = "Vertical Accountability", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("EM ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
pem4 <-  plot(outEMVERACC, type = "ct", ylab = "Vertical Accountability", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("EM Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
pem5 <-  plot(outEMHORACC, type = "gap", ylab = "Horizontal Accountability", xlim = c(-10, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + ggtitle("EM ATT Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))
pem6 <-  plot(outEMHORACC, type = "ct", ylab = "Horizontal Accountability", xlim = c(-15, 15)) + theme(axis.text.x = element_text(angle = 0, size = 8, color = "gray60", vjust = 0)) + theme(axis.text.y = element_text(angle = 0, size = 8, color = "gray60", vjust = 0))+ ggtitle("EM Treated and Counterfactuals Latin America") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(10, 0, 10, 0))) + theme(axis.title.x = element_text(color = "black",size = 10, vjust = -0.35),axis.title.y = element_text(color = "black",size = 10, vjust = 0.35))}

#Figure A12. The effect of term limit evasion on the three democratic outcomes by Latin American countries(MC Method)
{pem7 <-  plot(outEMLIBDEM, type = "ct", id = "Argentina", ylab = "Liberal Democracy", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem8 <-  plot(outEMLIBDEM, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem9 <-  plot(outEMLIBDEM, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem10 <-  plot(outEMLIBDEM, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Liberal Democracy",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem11 <-  plot(outEMLIBDEM, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem12 <-  plot(outEMLIBDEM, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem13 <-  plot(outEMLIBDEM, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem14 <-  plot(outEMLIBDEM, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem15 <-  plot(outEMLIBDEM, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem16 <-  plot(outEMLIBDEM, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Liberal Democracy", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
  
pem17 <-  plot(outEMVERACC, type = "ct", id = "Argentina", ylab = "Vertical Accountability", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem18 <-  plot(outEMVERACC, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem19 <-  plot(outEMVERACC, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem20 <-  plot(outEMVERACC, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Vertical Accountability",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem21 <-  plot(outEMVERACC, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem22 <-  plot(outEMVERACC, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem23 <-  plot(outEMVERACC, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem24 <-  plot(outEMVERACC, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem25 <-  plot(outEMVERACC, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem26 <-  plot(outEMVERACC, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Vertical Accountability", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
  
pem27 <-  plot(outEMHORACC, type = "ct", id = "Argentina", ylab = "Horizontal Accountability", xlim = c(1984, 2008),theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Argentina") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem28 <-  plot(outEMHORACC, type = "ct", id = "Bolivia", xlim = c(1994, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Bolivia") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem29 <-  plot(outEMHORACC, type = "ct", id = "Brazil", xlim = c(1985, 2011), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Brazil") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem30 <-  plot(outEMHORACC, type = "ct", id = "Colombia", xlim = c(1989, 2018), ylab = "Horizontal Accountability",theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Colombia ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem31 <-  plot(outEMHORACC, type = "ct", id = "Dominican Republic", xlim = c(1995, 2016), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Dominican Republic ") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem32 <-  plot(outEMHORACC, type = "ct", id = "Ecuador", xlim = c(1993, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Ecuador") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem33 <-  plot(outEMHORACC, type = "ct", id = "Honduras", xlim = c(2000, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Honduras") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem34 <-  plot(outEMHORACC, type = "ct", id = "Nicaragua", xlim = c(1996, 2018), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Nicaragua") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem35 <-  plot(outEMHORACC, type = "ct", id = "Peru", xlim = c(1983, 2007), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = TRUE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Peru") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))
pem36 <-  plot(outEMHORACC, type = "ct", id = "Venezuela", xlim = c(1984, 2013), ylab = "Horizontal Accountability", theme.bw = TRUE, legendOff = FALSE) + theme(axis.text.y = element_text(angle = 0, size = 8, vjust = 0)) + ggtitle("Venezuela") +theme(plot.title = element_text(size = 10, face = "bold",margin = margin(1, 0, 1, 0)))}
